.. image:: https://github.com/MacHu-GWU/pygitrepo-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/pygitrepo-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/pygitrepo-project/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/pygitrepo-project

.. image:: https://readthedocs.org/projects/pygitrepo/badge/?version=latest
    :target: https://pygitrepo.readthedocs.io/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/pygitrepo.svg
    :target: https://pypi.python.org/pypi/pygitrepo

.. image:: https://img.shields.io/pypi/pyversions/pygitrepo.svg
    :target: https://pypi.python.org/pypi/pygitrepo

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/pygitrepo-project

------


.. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: http://pygitrepo.my-docs.com/index.html

.. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: http://pygitrepo.my-docs.com/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Source_Code-blue.svg
    :target: http://pygitrepo.my-docs.com/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/pygitrepo-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/pygitrepo-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/pygitrepo-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/pygitrepo#files


欢迎来到 ``pygitrepo`` 文档
==============================================================================

- `English document is here <https://pygitrepo.readthedocs.io/index.html>`_
- `中文文档在此 <https://pygitrepo.readthedocs.io/index_cn.html>`_

``pygitrepo`` 是一款简化 Python 库开发工作流的命令行工具. 内置了包括: 虚拟环境, 单元测试, 文档构建, 文档部署, 打包分发, CI 自动化, 多操作系统多版本矩阵测试, 等很多开发模式的 **最佳实践**.

功能:

1. Python 库, 或是面向开源的 PyPI 包的开发工作流.
2. 基于 AWS Lambda 的微服务开发, 测试, 部署工作流.


.. _install:

Install
------------------------------------------------------------------------------

``pygitrepo`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install pygitrepo

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade pygitrepo
